@@ -1,16 +1,17 @@
-#' Create favicons from package logo
+#' Initialise favicons from package logo
 #'
+#' @description
 #' This function auto-detects the location of your package logo (with the name
-#' `logo.svg` (recommended format) or `logo.png`) and runs it through the
-#' <https://realfavicongenerator.net> API to build a complete set of favicons
-#' with different sizes, as needed for modern web usage.
+#' `logo.svg` (recommended format) or `logo.png`, created with `usethis::use_logo()`)
+#' and runs it through the <https://realfavicongenerator.net> API to build a
+#' complete set of favicons with different sizes, as needed for modern web usage.
 #'
 #' You only need to run the function once. The favicon set will be stored in
 #' `pkgdown/favicon` and copied by [init_site()] to the relevant location when
 #' the website is rebuilt.
 #'
 #' Once complete, you should add `pkgdown/` to `.Rbuildignore ` to avoid a NOTE
-#' during package checking.
+#' during package checking. (`usethis::use_logo()` does this for you!)
 #'
 #' @inheritParams as_pkgdown
 #' @param overwrite If `TRUE`, re-create favicons from package logo.
@@ -39,11 +40,10 @@ build_favicons <- function(pkg = ".", overwrite = FALSE) {
   }
 
   cli::cli_inform(c(
-    i = "Building favicons with {.url https://realfavicongenerator.net} ..."
+    i = "Building favicons with {.url https://realfavicongenerator.net}..."
   ))
 
-  logo <- readBin(logo_path, what = "raw", n = fs::file_info(logo_path)$size)
-
+  logo <- readBin(logo_path, what = "raw", n = file_info(logo_path)$size)
   json_request <- list(
     "favicon_generation" = list(
       "api_key" = "87d5cd739b05c00416c4a19cd14a8bb5632ea563",
@@ -65,43 +65,37 @@ build_favicons <- function(pkg = ".", overwrite = FALSE) {
       )
     )
   )
+  req <- httr2::request("https://realfavicongenerator.net/api/favicon")
+  req <- httr2::req_body_json(req, json_request)
 
-  resp <- httr::RETRY(
-    "POST",
-    "https://realfavicongenerator.net/api/favicon",
-    body = json_request,
-    encode = "json",
-    quiet = TRUE
+  withCallingHandlers(
+    resp <- httr2::req_perform(req),
+    error = function(e) {
+      cli::cli_abort("API request failed.", parent = e)
+    }
   )
-  if (httr::http_error(resp)) {
-    cli::cli_abort("API request failed.", call = caller_env())
-  }
 
-  content <- httr::content(resp)
+  content <- httr2::resp_body_json(resp)
   result <- content$favicon_generation_result
 
   if (!identical(result$result$status, "success")) {
     cli::cli_abort("API request failed.", .internal = TRUE)
   }
 
-  tmp <- tempfile()
-  on.exit(unlink(tmp))
-  result <- httr::RETRY(
-    "GET",
-    result$favicon$package_url,
-    httr::write_disk(tmp),
-    quiet = TRUE
-  )
+  tmp <- withr::local_tempfile()
+  req <- httr2::request(result$favicon$package_url)
+  resp <- httr2::req_perform(req, tmp)
 
-  tryCatch({
-    utils::unzip(tmp, exdir = path(pkg$src_path, "pkgdown", "favicon"))
-  },
-  warning = function(e) {
-    cli::cli_abort("Your logo file couldn't be processed and may be corrupt.", parent = e)
-  },
-  error = function(e) {
-    cli::cli_abort("Your logo file couldn't be processed and may be corrupt.", parent = e)
-  })
+  withCallingHandlers(
+    paths <- utils::unzip(tmp, exdir = path(pkg$src_path, "pkgdown", "favicon")),
+    warning = function(e) {
+      cli::cli_abort("Your logo file couldn't be processed and may be corrupt.", parent = e)
+    },
+    error = function(e) {
+      cli::cli_abort("Your logo file couldn't be processed and may be corrupt.", parent = e)
+    }
+  )
+  cli::cli_inform(c("v" = "Added {.path {sort(path_file(paths))}}."))
 
   invisible()
 }
@@ -109,15 +103,19 @@ build_favicons <- function(pkg = ".", overwrite = FALSE) {
 copy_favicons <- function(pkg = ".") {
   pkg <- as_pkgdown(pkg)
 
-  favicons <- path(pkg$src_path, "pkgdown", "favicon")
-  if (!dir_exists(favicons))
-    return()
-
-  dir_copy_to(pkg, favicons, pkg$dst_path)
+  dir_copy_to(
+    src_dir = path(pkg$src_path, "pkgdown", "favicon"),
+    src_root = pkg$src_path,
+    dst_dir = pkg$dst_path,
+    dst_root = pkg$dst_path
+  )
 }
 
 has_favicons <- function(pkg = ".") {
   pkg <- as_pkgdown(pkg)
+  unname(file_exists(path_favicons(pkg)))
+}
 
-  file.exists(path(pkg$src_path, "pkgdown", "favicon"))
+path_favicons <- function(pkg) {
+  path(pkg$src_path, "pkgdown", "favicon")
 }
