@@ -1,5 +1,5 @@
 test_that("missing logo generates message", {
-  pkg <- local_pkgdown_site(test_path("assets/site-empty"))
+  pkg <- local_pkgdown_site()
 
   expect_snapshot(error = TRUE,
     expect_output(build_favicons(pkg), "Building favicons")
@@ -7,7 +7,10 @@ test_that("missing logo generates message", {
 })
 
 test_that("existing logo generates message", {
-  pkg <- local_pkgdown_site(test_path("assets/site-favicons"))
+  pkg <- local_pkgdown_site()
+  dir_create(path(pkg$src_path, "pkgdown", "favicon"))
+  file_create(path(pkg$src_path, "pkgdown", "favicon", "favicon.ico"))
+  file_create(path(pkg$src_path, "logo.png"))
 
   expect_true(has_favicons(pkg))
   expect_snapshot(build_favicons(pkg))
